# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`etckeeper`](#etckeeper): Installs etckeeper.
* [`etckeeper::config`](#etckeeperconfig)
* [`etckeeper::install`](#etckeeperinstall)

### Defined types

* [`etckeeper::ignore`](#etckeeperignore): Add a glob pattern for the chosen VCS to ignore.

### Data types

* [`Etckeeper::PackageManager::HighLevel`](#etckeeperpackagemanagerhighlevel)
* [`Etckeeper::PackageManager::LowLevel`](#etckeeperpackagemanagerlowlevel)
* [`Etckeeper::VCS`](#etckeepervcs)

## Classes

### <a name="etckeeper"></a>`etckeeper`

Installs etckeeper.

* **Since** 1.0.0

* **See also**
  * puppet_defined_types::etckeeper::ignore
    * etckeeper::ignore

#### Examples

##### Declaring the class

```puppet
include etckeeper
```

##### Choosing a specific VCS instead of the default

```puppet
class { 'etckeeper':
  vcs => 'bzr',
}
```

##### Forcing the user name & email for commits

```puppet
class { 'etckeeper':
  vcs            => 'git',
  vcs_user_name  => 'Alice',
  vcs_user_email => 'alice@example.com',
}
```

#### Parameters

The following parameters are available in the `etckeeper` class:

* [`avoid_commit_before_install`](#avoid_commit_before_install)
* [`avoid_daily_autocommits`](#avoid_daily_autocommits)
* [`avoid_special_file_warning`](#avoid_special_file_warning)
* [`bzr_commit_options`](#bzr_commit_options)
* [`conf_dir`](#conf_dir)
* [`darcs_commit_options`](#darcs_commit_options)
* [`git_commit_options`](#git_commit_options)
* [`hg_commit_options`](#hg_commit_options)
* [`highlevel_package_manager`](#highlevel_package_manager)
* [`lowlevel_package_manager`](#lowlevel_package_manager)
* [`manage_vcs_package`](#manage_vcs_package)
* [`package_name`](#package_name)
* [`push_remotes`](#push_remotes)
* [`vcs`](#vcs)
* [`vcs_packages`](#vcs_packages)
* [`vcs_user_email`](#vcs_user_email)
* [`vcs_user_name`](#vcs_user_name)

##### <a name="avoid_commit_before_install"></a>`avoid_commit_before_install`

Data type: `Optional[Boolean]`



##### <a name="avoid_daily_autocommits"></a>`avoid_daily_autocommits`

Data type: `Optional[Boolean]`



##### <a name="avoid_special_file_warning"></a>`avoid_special_file_warning`

Data type: `Optional[Boolean]`



##### <a name="bzr_commit_options"></a>`bzr_commit_options`

Data type: `Optional[String]`



##### <a name="conf_dir"></a>`conf_dir`

Data type: `Stdlib::Absolutepath`

Top-level configuration directory, usually `/etc/etckeeper`.

##### <a name="darcs_commit_options"></a>`darcs_commit_options`

Data type: `Optional[String]`



##### <a name="git_commit_options"></a>`git_commit_options`

Data type: `Optional[String]`



##### <a name="hg_commit_options"></a>`hg_commit_options`

Data type: `Optional[String]`



##### <a name="highlevel_package_manager"></a>`highlevel_package_manager`

Data type: `Etckeeper::PackageManager::HighLevel`



##### <a name="lowlevel_package_manager"></a>`lowlevel_package_manager`

Data type: `Etckeeper::PackageManager::LowLevel`



##### <a name="manage_vcs_package"></a>`manage_vcs_package`

Data type: `Boolean`



##### <a name="package_name"></a>`package_name`

Data type: `String`

The name of the package.

##### <a name="push_remotes"></a>`push_remotes`

Data type: `Optional[Array[String, 1]]`



##### <a name="vcs"></a>`vcs`

Data type: `Etckeeper::VCS`



##### <a name="vcs_packages"></a>`vcs_packages`

Data type: `Hash[Etckeeper::VCS, String]`

Hash of VCS to the package that provides it.

##### <a name="vcs_user_email"></a>`vcs_user_email`

Data type: `Optional[String[1]]`



##### <a name="vcs_user_name"></a>`vcs_user_name`

Data type: `Optional[String[1]]`



### <a name="etckeeperconfig"></a>`etckeeper::config`

The etckeeper::config class.

### <a name="etckeeperinstall"></a>`etckeeper::install`

The etckeeper::install class.

## Defined types

### <a name="etckeeperignore"></a>`etckeeper::ignore`

Add a glob pattern for the chosen VCS to ignore.

* **Since** 1.2.0

* **See also**
  * puppet_classes::etckeeper
    * etckeeper

#### Examples

##### Ignoring an example pattern

```puppet
etckeeper::ignore { '*.foo':
  ensure => present,
}
```

#### Parameters

The following parameters are available in the `etckeeper::ignore` defined type:

* [`ensure`](#ensure)
* [`glob`](#glob)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`



Default value: `'present'`

##### <a name="glob"></a>`glob`

Data type: `String[1]`

The pattern to ignore.

Default value: `$title`

## Data types

### <a name="etckeeperpackagemanagerhighlevel"></a>`Etckeeper::PackageManager::HighLevel`

The Etckeeper::PackageManager::HighLevel data type.

* **Since** 1.0.0

Alias of

```puppet
Enum['apt', 'yum', 'zypper', 'pacman']
```

### <a name="etckeeperpackagemanagerlowlevel"></a>`Etckeeper::PackageManager::LowLevel`

The Etckeeper::PackageManager::LowLevel data type.

* **Since** 1.0.0

Alias of

```puppet
Enum['dpkg', 'rpm', 'pacman']
```

### <a name="etckeepervcs"></a>`Etckeeper::VCS`

The Etckeeper::VCS data type.

* **Since** 1.0.0

Alias of

```puppet
Enum['bzr', 'darcs', 'git', 'hg']
```

